# coding: utf-8

"""
    Visier Administration APIs

    Visier APIs for managing your tenant or tenants in Visier. You can programmatically manage user accounts in Visier, the profiles and permissions assigned to users, and to make changes in projects and publish projects to production. Administrating tenant users can use administration APIs to manage their analytic tenants and consolidated analytics tenants.<br>**Note:** If you submit API requests for changes that cause a project to publish to production (such as assigning permissions to users or updating permissions), each request is individually published to production, resulting in hundreds or thousands of production versions. We recommend that you use the `ProjectID` request header to make changes in a project, if `ProjectID` is available for the API endpoint.

    The version of the OpenAPI document: 22222222.99201.1793
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from visier_api_core import ApiClient, ApiResponse, RequestSerialized, RESTResponseType

from pydantic import Field, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from visier_api_administration.models.servicing_publicapi_transfers_get_production_versions_api_response_dto import ServicingPublicapiTransfersGetProductionVersionsAPIResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_production_version_api_operation_request_dto import ServicingPublicapiTransfersProductionVersionAPIOperationRequestDTO
from visier_api_administration.models.servicing_publicapi_transfers_production_version_api_operation_response_dto import ServicingPublicapiTransfersProductionVersionAPIOperationResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_production_versions_api_operation_request_dto import ServicingPublicapiTransfersProductionVersionsAPIOperationRequestDTO
from visier_api_administration.models.servicing_publicapi_transfers_production_versions_api_operation_response_dto import ServicingPublicapiTransfersProductionVersionsAPIOperationResponseDTO
import visier_api_administration.models


class ProductionVersionsApi:
    """
    This class provides methods to make requests to the Visier API.
    It uses the ApiClient to handle the HTTP requests and responses.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_production_versions(
        self,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of production versions to return. Default is 400.")] = None,
        start: Annotated[Optional[StrictInt], Field(description="The starting index of the first production version to return. Default is 0.")] = None,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ServicingPublicapiTransfersGetProductionVersionsAPIResponseDTO:
        """Retrieve a list of all production versions

        Retrieve a list of all projects that were published to production, ordered from latest published to earliest published.   <br>**Note:** <em>This API is in **beta**. While in beta, APIs are interface-stable and implementation may change without notice. Rarely, interface changes may occur that are not backwards-compatible and require advance communication.  If you are interested in using this API, please contact your Customer Success Manager (CSM).</em>

        :param limit: The maximum number of production versions to return. Default is 400.
        :type limit: int
        :param start: The starting index of the first production version to return. Default is 0.
        :type start: int
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_production_versions_serialize(
            limit=limit,
            start=start,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ServicingPublicapiTransfersGetProductionVersionsAPIResponseDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_administration.models,
            response_data=response_data,
            response_types_map=_response_types_map
        ).data


    @validate_call
    def get_production_versions_with_http_info(
        self,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of production versions to return. Default is 400.")] = None,
        start: Annotated[Optional[StrictInt], Field(description="The starting index of the first production version to return. Default is 0.")] = None,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ServicingPublicapiTransfersGetProductionVersionsAPIResponseDTO]:
        """Retrieve a list of all production versions

        Retrieve a list of all projects that were published to production, ordered from latest published to earliest published.   <br>**Note:** <em>This API is in **beta**. While in beta, APIs are interface-stable and implementation may change without notice. Rarely, interface changes may occur that are not backwards-compatible and require advance communication.  If you are interested in using this API, please contact your Customer Success Manager (CSM).</em>

        :param limit: The maximum number of production versions to return. Default is 400.
        :type limit: int
        :param start: The starting index of the first production version to return. Default is 0.
        :type start: int
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_production_versions_serialize(
            limit=limit,
            start=start,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ServicingPublicapiTransfersGetProductionVersionsAPIResponseDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_administration.models,
            response_data=response_data,
            response_types_map=_response_types_map
        )


    @validate_call
    def get_production_versions_without_preload_content(
        self,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of production versions to return. Default is 400.")] = None,
        start: Annotated[Optional[StrictInt], Field(description="The starting index of the first production version to return. Default is 0.")] = None,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Retrieve a list of all production versions

        Retrieve a list of all projects that were published to production, ordered from latest published to earliest published.   <br>**Note:** <em>This API is in **beta**. While in beta, APIs are interface-stable and implementation may change without notice. Rarely, interface changes may occur that are not backwards-compatible and require advance communication.  If you are interested in using this API, please contact your Customer Success Manager (CSM).</em>

        :param limit: The maximum number of production versions to return. Default is 400.
        :type limit: int
        :param start: The starting index of the first production version to return. Default is 0.
        :type start: int
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_production_versions_serialize(
            limit=limit,
            start=start,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ServicingPublicapiTransfersGetProductionVersionsAPIResponseDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_production_versions_serialize(
        self,
        limit,
        start,
        target_tenant_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if start is not None:
            
            _query_params.append(('start', start))
            
        # process the header parameters
        if target_tenant_id is not None:
            _header_params['TargetTenantID'] = target_tenant_id
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'CookieAuth', 
            'ApiKeyAuth', 
            'OAuth2Auth', 
            'OAuth2Auth', 
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1beta/admin/production-versions',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def post_production_version(
        self,
        production_version_id: Annotated[StrictStr, Field(description="The production version to use as the target of the operation; for example, the production version to roll back to for the `rollBackTo` operation.")],
        servicing_publicapi_transfers_production_version_api_operation_request_dto: ServicingPublicapiTransfersProductionVersionAPIOperationRequestDTO,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ServicingPublicapiTransfersProductionVersionAPIOperationResponseDTO:
        """Perform an operation on a production version

        Perform operations on a specific production version. The following operations are supported:  * `rollBackTo`: Create a project that rolls back the production version to the specified version. The project contains uncommitted changes that reverse the published versions after the target production version.   <br>**Note:** <em>This API is in **beta**. While in beta, APIs are interface-stable and implementation may change without notice. Rarely, interface changes may occur that are not backwards-compatible and require advance communication.  If you are interested in using this API, please contact your Customer Success Manager (CSM).</em>

        :param production_version_id: The production version to use as the target of the operation; for example, the production version to roll back to for the `rollBackTo` operation. (required)
        :type production_version_id: str
        :param servicing_publicapi_transfers_production_version_api_operation_request_dto: (required)
        :type servicing_publicapi_transfers_production_version_api_operation_request_dto: ServicingPublicapiTransfersProductionVersionAPIOperationRequestDTO
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_production_version_serialize(
            production_version_id=production_version_id,
            servicing_publicapi_transfers_production_version_api_operation_request_dto=servicing_publicapi_transfers_production_version_api_operation_request_dto,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ServicingPublicapiTransfersProductionVersionAPIOperationResponseDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_administration.models,
            response_data=response_data,
            response_types_map=_response_types_map
        ).data


    @validate_call
    def post_production_version_with_http_info(
        self,
        production_version_id: Annotated[StrictStr, Field(description="The production version to use as the target of the operation; for example, the production version to roll back to for the `rollBackTo` operation.")],
        servicing_publicapi_transfers_production_version_api_operation_request_dto: ServicingPublicapiTransfersProductionVersionAPIOperationRequestDTO,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ServicingPublicapiTransfersProductionVersionAPIOperationResponseDTO]:
        """Perform an operation on a production version

        Perform operations on a specific production version. The following operations are supported:  * `rollBackTo`: Create a project that rolls back the production version to the specified version. The project contains uncommitted changes that reverse the published versions after the target production version.   <br>**Note:** <em>This API is in **beta**. While in beta, APIs are interface-stable and implementation may change without notice. Rarely, interface changes may occur that are not backwards-compatible and require advance communication.  If you are interested in using this API, please contact your Customer Success Manager (CSM).</em>

        :param production_version_id: The production version to use as the target of the operation; for example, the production version to roll back to for the `rollBackTo` operation. (required)
        :type production_version_id: str
        :param servicing_publicapi_transfers_production_version_api_operation_request_dto: (required)
        :type servicing_publicapi_transfers_production_version_api_operation_request_dto: ServicingPublicapiTransfersProductionVersionAPIOperationRequestDTO
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_production_version_serialize(
            production_version_id=production_version_id,
            servicing_publicapi_transfers_production_version_api_operation_request_dto=servicing_publicapi_transfers_production_version_api_operation_request_dto,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ServicingPublicapiTransfersProductionVersionAPIOperationResponseDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_administration.models,
            response_data=response_data,
            response_types_map=_response_types_map
        )


    @validate_call
    def post_production_version_without_preload_content(
        self,
        production_version_id: Annotated[StrictStr, Field(description="The production version to use as the target of the operation; for example, the production version to roll back to for the `rollBackTo` operation.")],
        servicing_publicapi_transfers_production_version_api_operation_request_dto: ServicingPublicapiTransfersProductionVersionAPIOperationRequestDTO,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Perform an operation on a production version

        Perform operations on a specific production version. The following operations are supported:  * `rollBackTo`: Create a project that rolls back the production version to the specified version. The project contains uncommitted changes that reverse the published versions after the target production version.   <br>**Note:** <em>This API is in **beta**. While in beta, APIs are interface-stable and implementation may change without notice. Rarely, interface changes may occur that are not backwards-compatible and require advance communication.  If you are interested in using this API, please contact your Customer Success Manager (CSM).</em>

        :param production_version_id: The production version to use as the target of the operation; for example, the production version to roll back to for the `rollBackTo` operation. (required)
        :type production_version_id: str
        :param servicing_publicapi_transfers_production_version_api_operation_request_dto: (required)
        :type servicing_publicapi_transfers_production_version_api_operation_request_dto: ServicingPublicapiTransfersProductionVersionAPIOperationRequestDTO
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_production_version_serialize(
            production_version_id=production_version_id,
            servicing_publicapi_transfers_production_version_api_operation_request_dto=servicing_publicapi_transfers_production_version_api_operation_request_dto,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ServicingPublicapiTransfersProductionVersionAPIOperationResponseDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _post_production_version_serialize(
        self,
        production_version_id,
        servicing_publicapi_transfers_production_version_api_operation_request_dto,
        target_tenant_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if production_version_id is not None:
            _path_params['productionVersionId'] = production_version_id
        # process the query parameters
        # process the header parameters
        if target_tenant_id is not None:
            _header_params['TargetTenantID'] = target_tenant_id
        # process the form parameters
        # process the body parameter
        if servicing_publicapi_transfers_production_version_api_operation_request_dto is not None:
            _body_params = servicing_publicapi_transfers_production_version_api_operation_request_dto


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'CookieAuth', 
            'ApiKeyAuth', 
            'OAuth2Auth', 
            'OAuth2Auth', 
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v1beta/admin/production-versions/{productionVersionId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def post_production_versions(
        self,
        servicing_publicapi_transfers_production_versions_api_operation_request_dto: ServicingPublicapiTransfersProductionVersionsAPIOperationRequestDTO,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ServicingPublicapiTransfersProductionVersionsAPIOperationResponseDTO:
        """Perform an operation on production versions

        Perform operations on production versions, such as exporting a production project's committed changes.     If exporting, please specify `Accept: application/zip, application/json` in the header. The API returns exported changes in ZIP format and error messages in JSON format. If your request returns an error and it doesn't accept `application/json`, you will receive an HTTP 406 status code instead of the appropriate error response body.   <br>**Note:** <em>This API is in **beta**. While in beta, APIs are interface-stable and implementation may change without notice. Rarely, interface changes may occur that are not backwards-compatible and require advance communication.  If you are interested in using this API, please contact your Customer Success Manager (CSM).</em>

        :param servicing_publicapi_transfers_production_versions_api_operation_request_dto: (required)
        :type servicing_publicapi_transfers_production_versions_api_operation_request_dto: ServicingPublicapiTransfersProductionVersionsAPIOperationRequestDTO
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_production_versions_serialize(
            servicing_publicapi_transfers_production_versions_api_operation_request_dto=servicing_publicapi_transfers_production_versions_api_operation_request_dto,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ServicingPublicapiTransfersProductionVersionsAPIOperationResponseDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_administration.models,
            response_data=response_data,
            response_types_map=_response_types_map
        ).data


    @validate_call
    def post_production_versions_with_http_info(
        self,
        servicing_publicapi_transfers_production_versions_api_operation_request_dto: ServicingPublicapiTransfersProductionVersionsAPIOperationRequestDTO,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ServicingPublicapiTransfersProductionVersionsAPIOperationResponseDTO]:
        """Perform an operation on production versions

        Perform operations on production versions, such as exporting a production project's committed changes.     If exporting, please specify `Accept: application/zip, application/json` in the header. The API returns exported changes in ZIP format and error messages in JSON format. If your request returns an error and it doesn't accept `application/json`, you will receive an HTTP 406 status code instead of the appropriate error response body.   <br>**Note:** <em>This API is in **beta**. While in beta, APIs are interface-stable and implementation may change without notice. Rarely, interface changes may occur that are not backwards-compatible and require advance communication.  If you are interested in using this API, please contact your Customer Success Manager (CSM).</em>

        :param servicing_publicapi_transfers_production_versions_api_operation_request_dto: (required)
        :type servicing_publicapi_transfers_production_versions_api_operation_request_dto: ServicingPublicapiTransfersProductionVersionsAPIOperationRequestDTO
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_production_versions_serialize(
            servicing_publicapi_transfers_production_versions_api_operation_request_dto=servicing_publicapi_transfers_production_versions_api_operation_request_dto,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ServicingPublicapiTransfersProductionVersionsAPIOperationResponseDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_administration.models,
            response_data=response_data,
            response_types_map=_response_types_map
        )


    @validate_call
    def post_production_versions_without_preload_content(
        self,
        servicing_publicapi_transfers_production_versions_api_operation_request_dto: ServicingPublicapiTransfersProductionVersionsAPIOperationRequestDTO,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Perform an operation on production versions

        Perform operations on production versions, such as exporting a production project's committed changes.     If exporting, please specify `Accept: application/zip, application/json` in the header. The API returns exported changes in ZIP format and error messages in JSON format. If your request returns an error and it doesn't accept `application/json`, you will receive an HTTP 406 status code instead of the appropriate error response body.   <br>**Note:** <em>This API is in **beta**. While in beta, APIs are interface-stable and implementation may change without notice. Rarely, interface changes may occur that are not backwards-compatible and require advance communication.  If you are interested in using this API, please contact your Customer Success Manager (CSM).</em>

        :param servicing_publicapi_transfers_production_versions_api_operation_request_dto: (required)
        :type servicing_publicapi_transfers_production_versions_api_operation_request_dto: ServicingPublicapiTransfersProductionVersionsAPIOperationRequestDTO
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_production_versions_serialize(
            servicing_publicapi_transfers_production_versions_api_operation_request_dto=servicing_publicapi_transfers_production_versions_api_operation_request_dto,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ServicingPublicapiTransfersProductionVersionsAPIOperationResponseDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _post_production_versions_serialize(
        self,
        servicing_publicapi_transfers_production_versions_api_operation_request_dto,
        target_tenant_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if target_tenant_id is not None:
            _header_params['TargetTenantID'] = target_tenant_id
        # process the form parameters
        # process the body parameter
        if servicing_publicapi_transfers_production_versions_api_operation_request_dto is not None:
            _body_params = servicing_publicapi_transfers_production_versions_api_operation_request_dto


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'CookieAuth', 
            'ApiKeyAuth', 
            'OAuth2Auth', 
            'OAuth2Auth', 
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v1beta/admin/production-versions',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

# flake8: noqa

"""
    Visier Administration APIs

    Visier APIs for managing your tenant or tenants in Visier. You can programmatically manage user accounts in Visier, the profiles and permissions assigned to users, and to make changes in projects and publish projects to production. Administrating tenant users can use administration APIs to manage their analytic tenants and consolidated analytics tenants.<br>**Note:** If you submit API requests for changes that cause a project to publish to production (such as assigning permissions to users or updating permissions), each request is individually published to production, resulting in hundreds or thousands of production versions. We recommend that you use the `ProjectID` request header to make changes in a project, if `ProjectID` is available for the API endpoint.

    The version of the OpenAPI document: 22222222.99201.1793
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


__version__ = "0.99201.1793"

# import apis into sdk package
from visier_api_administration.api.consolidated_analytics_api import ConsolidatedAnalyticsApi
from visier_api_administration.api.email_domains_api import EmailDomainsApi
from visier_api_administration.api.encryption_keys_api import EncryptionKeysApi
from visier_api_administration.api.permissions_api import PermissionsApi
from visier_api_administration.api.production_versions_api import ProductionVersionsApi
from visier_api_administration.api.profiles_api import ProfilesApi
from visier_api_administration.api.projects_api import ProjectsApi
from visier_api_administration.api.sources_api import SourcesApi
from visier_api_administration.api.system_status_api import SystemStatusApi
from visier_api_administration.api.tenants_v1_api import TenantsV1Api
from visier_api_administration.api.tenants_v2_api import TenantsV2Api
from visier_api_administration.api.user_groups_v2_api import UserGroupsV2Api
from visier_api_administration.api.users_v1_api import UsersV1Api
from visier_api_administration.api.users_v2_api import UsersV2Api


# import models into sdk package
from visier_api_administration.models.admin_delete_user_group_v2_request import AdminDeleteUserGroupV2Request
from visier_api_administration.models.admin_excluded_sources_body import AdminExcludedSourcesBody
from visier_api_administration.models.admin_key_name import AdminKeyName
from visier_api_administration.models.admin_mask_message import AdminMaskMessage
from visier_api_administration.models.admin_permissions_list_dto import AdminPermissionsListDTO
from visier_api_administration.models.admin_publicapi_transfers_all_tenants_status_apidto import AdminPublicapiTransfersAllTenantsStatusAPIDTO
from visier_api_administration.models.admin_publicapi_transfers_batch_tenant_provision_apidto import AdminPublicapiTransfersBatchTenantProvisionAPIDTO
from visier_api_administration.models.admin_publicapi_transfers_business_location_dto import AdminPublicapiTransfersBusinessLocationDTO
from visier_api_administration.models.admin_publicapi_transfers_custom_property_dto import AdminPublicapiTransfersCustomPropertyDTO
from visier_api_administration.models.admin_publicapi_transfers_custom_tenant_property_dto import AdminPublicapiTransfersCustomTenantPropertyDTO
from visier_api_administration.models.admin_publicapi_transfers_element_ids_dto import AdminPublicapiTransfersElementIDsDTO
from visier_api_administration.models.admin_publicapi_transfers_home_analysis_by_user_group_dto import AdminPublicapiTransfersHomeAnalysisByUserGroupDTO
from visier_api_administration.models.admin_publicapi_transfers_tenant_detail_apidto import AdminPublicapiTransfersTenantDetailAPIDTO
from visier_api_administration.models.admin_publicapi_transfers_tenant_management_api_get_response_dto import AdminPublicapiTransfersTenantManagementAPIGetResponseDTO
from visier_api_administration.models.admin_publicapi_transfers_tenant_management_api_list_response_dto import AdminPublicapiTransfersTenantManagementAPIListResponseDTO
from visier_api_administration.models.admin_publicapi_transfers_tenant_management_api_update_request_dto import AdminPublicapiTransfersTenantManagementAPIUpdateRequestDTO
from visier_api_administration.models.admin_publicapi_transfers_tenant_management_api_update_response_dto import AdminPublicapiTransfersTenantManagementAPIUpdateResponseDTO
from visier_api_administration.models.admin_publicapi_transfers_tenant_provision_apidto import AdminPublicapiTransfersTenantProvisionAPIDTO
from visier_api_administration.models.admin_publicapi_transfers_tenant_status_apidto import AdminPublicapiTransfersTenantStatusAPIDTO
from visier_api_administration.models.admin_publicapi_transfers_user_group_change_definition_dto import AdminPublicapiTransfersUserGroupChangeDefinitionDTO
from visier_api_administration.models.admin_publicapi_transfers_user_group_change_dimension_filter_dto import AdminPublicapiTransfersUserGroupChangeDimensionFilterDTO
from visier_api_administration.models.admin_publicapi_transfers_user_group_change_failure_dto import AdminPublicapiTransfersUserGroupChangeFailureDTO
from visier_api_administration.models.admin_publicapi_transfers_user_group_change_filter_dto import AdminPublicapiTransfersUserGroupChangeFilterDTO
from visier_api_administration.models.admin_publicapi_transfers_user_group_change_member_selection_dto import AdminPublicapiTransfersUserGroupChangeMemberSelectionDTO
from visier_api_administration.models.admin_publicapi_transfers_user_group_change_response_dto import AdminPublicapiTransfersUserGroupChangeResponseDTO
from visier_api_administration.models.admin_publicapi_transfers_user_group_change_success_dto import AdminPublicapiTransfersUserGroupChangeSuccessDTO
from visier_api_administration.models.admin_publicapi_transfers_user_group_change_users_dto import AdminPublicapiTransfersUserGroupChangeUsersDTO
from visier_api_administration.models.admin_publicapi_transfers_user_group_delete_dto import AdminPublicapiTransfersUserGroupDeleteDTO
from visier_api_administration.models.admin_publicapi_transfers_user_group_delete_failure_dto import AdminPublicapiTransfersUserGroupDeleteFailureDTO
from visier_api_administration.models.admin_publicapi_transfers_user_group_delete_response_dto import AdminPublicapiTransfersUserGroupDeleteResponseDTO
from visier_api_administration.models.admin_publicapi_transfers_user_group_delete_success_dto import AdminPublicapiTransfersUserGroupDeleteSuccessDTO
from visier_api_administration.models.admin_publicapi_transfers_user_group_filters_dto import AdminPublicapiTransfersUserGroupFiltersDTO
from visier_api_administration.models.admin_publicapi_transfers_user_group_single_delete_response_dto import AdminPublicapiTransfersUserGroupSingleDeleteResponseDTO
from visier_api_administration.models.admin_publicapi_transfers_user_groups_change_dto import AdminPublicapiTransfersUserGroupsChangeDTO
from visier_api_administration.models.admin_publicapi_transfers_user_groups_delete_request_dto import AdminPublicapiTransfersUserGroupsDeleteRequestDTO
from visier_api_administration.models.admin_put_project_commits_request import AdminPutProjectCommitsRequest
from visier_api_administration.models.admin_tenant_code_body import AdminTenantCodeBody
from visier_api_administration.models.admin_transfers_consolidated_analytics_api_excluded_source_list_dto import AdminTransfersConsolidatedAnalyticsAPIExcludedSourceListDTO
from visier_api_administration.models.admin_transfers_consolidated_analytics_api_source_tenant_list_dto import AdminTransfersConsolidatedAnalyticsAPISourceTenantListDTO
from visier_api_administration.models.admin_transfers_consolidated_analytics_api_tenant_create_request_dto import AdminTransfersConsolidatedAnalyticsAPITenantCreateRequestDTO
from visier_api_administration.models.admin_transfers_consolidated_analytics_api_tenant_list_response_dto import AdminTransfersConsolidatedAnalyticsAPITenantListResponseDTO
from visier_api_administration.models.admin_transfers_consolidated_analytics_api_tenant_with_details import AdminTransfersConsolidatedAnalyticsAPITenantWithDetails
from visier_api_administration.models.admin_transfers_consolidated_analytics_api_tenant_with_details_list_response_dto import AdminTransfersConsolidatedAnalyticsAPITenantWithDetailsListResponseDTO
from visier_api_administration.models.admin_transfers_email_domains_dto import AdminTransfersEmailDomainsDTO
from visier_api_administration.models.admin_transfers_permission_response_dto import AdminTransfersPermissionResponseDTO
from visier_api_administration.models.admin_transfers_permissions_to_user_group_for_tenant_dto import AdminTransfersPermissionsToUserGroupForTenantDTO
from visier_api_administration.models.admin_transfers_permissions_to_user_group_request_dto import AdminTransfersPermissionsToUserGroupRequestDTO
from visier_api_administration.models.admin_transfers_permissions_to_user_groups_request_dto import AdminTransfersPermissionsToUserGroupsRequestDTO
from visier_api_administration.models.admin_transfers_security_assignment_response_dto import AdminTransfersSecurityAssignmentResponseDTO
from visier_api_administration.models.admin_transfers_simple_user_dto import AdminTransfersSimpleUserDTO
from visier_api_administration.models.admin_transfers_target_project_for_tenant_dto import AdminTransfersTargetProjectForTenantDTO
from visier_api_administration.models.admin_transfers_target_project_for_tenants_list_dto import AdminTransfersTargetProjectForTenantsListDTO
from visier_api_administration.models.admin_transfers_tenant_assignments_dto import AdminTransfersTenantAssignmentsDTO
from visier_api_administration.models.admin_transfers_user_group_get_api_response_dto import AdminTransfersUserGroupGetAPIResponseDTO
from visier_api_administration.models.admin_transfers_user_groups_get_api_response_dto import AdminTransfersUserGroupsGetAPIResponseDTO
from visier_api_administration.models.admin_transfers_user_groups_users_dto import AdminTransfersUserGroupsUsersDTO
from visier_api_administration.models.admin_transfers_user_groups_users_for_tenant_dto import AdminTransfersUserGroupsUsersForTenantDTO
from visier_api_administration.models.admin_transfers_user_security_assignments_dto import AdminTransfersUserSecurityAssignmentsDTO
from visier_api_administration.models.admin_transfers_users_to_user_group_request_dto import AdminTransfersUsersToUserGroupRequestDTO
from visier_api_administration.models.admin_transfers_users_to_user_groups_request_dto import AdminTransfersUsersToUserGroupsRequestDTO
from visier_api_administration.models.admin_update_tenant_model import AdminUpdateTenantModel
from visier_api_administration.models.designer_crypto_generate_key_request_dto import DesignerCryptoGenerateKeyRequestDTO
from visier_api_administration.models.designer_crypto_tenant_encryption_key_dto import DesignerCryptoTenantEncryptionKeyDTO
from visier_api_administration.models.designer_crypto_tenant_encryption_key_details_dto import DesignerCryptoTenantEncryptionKeyDetailsDTO
from visier_api_administration.models.designer_transfers_module_settings_dto import DesignerTransfersModuleSettingsDTO
from visier_api_administration.models.designer_transfers_tenant_module_dto import DesignerTransfersTenantModuleDTO
from visier_api_administration.models.dp_automation_transfers_metric_validation_summary_dto import DpAutomationTransfersMetricValidationSummaryDTO
from visier_api_administration.models.dp_automation_transfers_tenant_preview_entries_summary_dto import DpAutomationTransfersTenantPreviewEntriesSummaryDTO
from visier_api_administration.models.dp_automation_transfers_tenant_preview_entries_summary_list_dto import DpAutomationTransfersTenantPreviewEntriesSummaryListDTO
from visier_api_administration.models.servicing_publicapi_transfers_accessible_tenant_profile_assignment_request_dto import ServicingPublicapiTransfersAccessibleTenantProfileAssignmentRequestDTO
from visier_api_administration.models.servicing_publicapi_transfers_accessible_tenant_profile_assignment_response_dto import ServicingPublicapiTransfersAccessibleTenantProfileAssignmentResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_accessible_tenant_profile_revoke_request_dto import ServicingPublicapiTransfersAccessibleTenantProfileRevokeRequestDTO
from visier_api_administration.models.servicing_publicapi_transfers_accessible_tenant_profile_revoke_response_dto import ServicingPublicapiTransfersAccessibleTenantProfileRevokeResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_additional_capabilities_dto import ServicingPublicapiTransfersAdditionalCapabilitiesDTO
from visier_api_administration.models.servicing_publicapi_transfers_admin_capability_config_dto import ServicingPublicapiTransfersAdminCapabilityConfigDTO
from visier_api_administration.models.servicing_publicapi_transfers_all_permissions_assigned_for_local_tenant_dto import ServicingPublicapiTransfersAllPermissionsAssignedForLocalTenantDTO
from visier_api_administration.models.servicing_publicapi_transfers_all_profile_assigned_for_accessible_tenant_dto import ServicingPublicapiTransfersAllProfileAssignedForAccessibleTenantDTO
from visier_api_administration.models.servicing_publicapi_transfers_all_profile_assigned_for_local_tenant_dto import ServicingPublicapiTransfersAllProfileAssignedForLocalTenantDTO
from visier_api_administration.models.servicing_publicapi_transfers_all_user_groups_assigned_for_local_tenant_dto import ServicingPublicapiTransfersAllUserGroupsAssignedForLocalTenantDTO
from visier_api_administration.models.servicing_publicapi_transfers_all_users_get_api_response_dto import ServicingPublicapiTransfersAllUsersGetAPIResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_analytic_object_dto import ServicingPublicapiTransfersAnalyticObjectDTO
from visier_api_administration.models.servicing_publicapi_transfers_assign_revoke_permission_by_permission_dto import ServicingPublicapiTransfersAssignRevokePermissionByPermissionDTO
from visier_api_administration.models.servicing_publicapi_transfers_assign_revoke_permission_by_tenant_dto import ServicingPublicapiTransfersAssignRevokePermissionByTenantDTO
from visier_api_administration.models.servicing_publicapi_transfers_assign_revoke_permission_by_user_dto import ServicingPublicapiTransfersAssignRevokePermissionByUserDTO
from visier_api_administration.models.servicing_publicapi_transfers_assign_revoke_permission_request_dto import ServicingPublicapiTransfersAssignRevokePermissionRequestDTO
from visier_api_administration.models.servicing_publicapi_transfers_assign_revoke_permissions_request_dto import ServicingPublicapiTransfersAssignRevokePermissionsRequestDTO
from visier_api_administration.models.servicing_publicapi_transfers_assign_revoke_permissions_response_dto import ServicingPublicapiTransfersAssignRevokePermissionsResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_bulk_data_access_set_response_dto import ServicingPublicapiTransfersBulkDataAccessSetResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_capabilities_dto import ServicingPublicapiTransfersCapabilitiesDTO
from visier_api_administration.models.servicing_publicapi_transfers_capability_dto import ServicingPublicapiTransfersCapabilityDTO
from visier_api_administration.models.servicing_publicapi_transfers_commit_and_publish_operation_response_dto import ServicingPublicapiTransfersCommitAndPublishOperationResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_commit_dto import ServicingPublicapiTransfersCommitDTO
from visier_api_administration.models.servicing_publicapi_transfers_content_package_dto import ServicingPublicapiTransfersContentPackageDTO
from visier_api_administration.models.servicing_publicapi_transfers_create_data_access_set_request_dto import ServicingPublicapiTransfersCreateDataAccessSetRequestDTO
from visier_api_administration.models.servicing_publicapi_transfers_data_access_set_dto import ServicingPublicapiTransfersDataAccessSetDTO
from visier_api_administration.models.servicing_publicapi_transfers_data_access_set_error_dto import ServicingPublicapiTransfersDataAccessSetErrorDTO
from visier_api_administration.models.servicing_publicapi_transfers_data_access_set_failure_dto import ServicingPublicapiTransfersDataAccessSetFailureDTO
from visier_api_administration.models.servicing_publicapi_transfers_data_access_set_success_dto import ServicingPublicapiTransfersDataAccessSetSuccessDTO
from visier_api_administration.models.servicing_publicapi_transfers_data_security_profile_dto import ServicingPublicapiTransfersDataSecurityProfileDTO
from visier_api_administration.models.servicing_publicapi_transfers_delete_permissions_request_dto import ServicingPublicapiTransfersDeletePermissionsRequestDTO
from visier_api_administration.models.servicing_publicapi_transfers_dimension_filter_dto import ServicingPublicapiTransfersDimensionFilterDTO
from visier_api_administration.models.servicing_publicapi_transfers_dynamic_dimension_filter_dto import ServicingPublicapiTransfersDynamicDimensionFilterDTO
from visier_api_administration.models.servicing_publicapi_transfers_dynamic_property_mapping_dto import ServicingPublicapiTransfersDynamicPropertyMappingDTO
from visier_api_administration.models.servicing_publicapi_transfers_error_dto import ServicingPublicapiTransfersErrorDTO
from visier_api_administration.models.servicing_publicapi_transfers_export_production_versions_api_operation_parameters_dto import ServicingPublicapiTransfersExportProductionVersionsAPIOperationParametersDTO
from visier_api_administration.models.servicing_publicapi_transfers_failed_accessible_tenant_profile_assignment_dto import ServicingPublicapiTransfersFailedAccessibleTenantProfileAssignmentDTO
from visier_api_administration.models.servicing_publicapi_transfers_failed_local_tenant_profile_assignment_dto import ServicingPublicapiTransfersFailedLocalTenantProfileAssignmentDTO
from visier_api_administration.models.servicing_publicapi_transfers_failed_local_tenant_profile_revoke_dto import ServicingPublicapiTransfersFailedLocalTenantProfileRevokeDTO
from visier_api_administration.models.servicing_publicapi_transfers_get_capabilities_api_response_dto import ServicingPublicapiTransfersGetCapabilitiesAPIResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_get_content_packages_api_response_dto import ServicingPublicapiTransfersGetContentPackagesAPIResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_get_data_access_sets_api_response_dto import ServicingPublicapiTransfersGetDataAccessSetsAPIResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_get_data_security_objects_api_response_dto import ServicingPublicapiTransfersGetDataSecurityObjectsAPIResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_get_permissions_api_response_dto import ServicingPublicapiTransfersGetPermissionsAPIResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_get_production_versions_api_response_dto import ServicingPublicapiTransfersGetProductionVersionsAPIResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_get_projects_api_response_dto import ServicingPublicapiTransfersGetProjectsAPIResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_hierarchy_property_dto import ServicingPublicapiTransfersHierarchyPropertyDTO
from visier_api_administration.models.servicing_publicapi_transfers_inherited_access_config_dto import ServicingPublicapiTransfersInheritedAccessConfigDTO
from visier_api_administration.models.servicing_publicapi_transfers_inherited_reference_member_filter_config_dto import ServicingPublicapiTransfersInheritedReferenceMemberFilterConfigDTO
from visier_api_administration.models.servicing_publicapi_transfers_last_login_dto import ServicingPublicapiTransfersLastLoginDTO
from visier_api_administration.models.servicing_publicapi_transfers_local_tenant_profile_assignment_request_dto import ServicingPublicapiTransfersLocalTenantProfileAssignmentRequestDTO
from visier_api_administration.models.servicing_publicapi_transfers_local_tenant_profile_assignment_response_dto import ServicingPublicapiTransfersLocalTenantProfileAssignmentResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_local_tenant_profile_revoke_request_dto import ServicingPublicapiTransfersLocalTenantProfileRevokeRequestDTO
from visier_api_administration.models.servicing_publicapi_transfers_local_tenant_profile_revoke_response_dto import ServicingPublicapiTransfersLocalTenantProfileRevokeResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_member_filter_config_dto import ServicingPublicapiTransfersMemberFilterConfigDTO
from visier_api_administration.models.servicing_publicapi_transfers_member_selection_dto import ServicingPublicapiTransfersMemberSelectionDTO
from visier_api_administration.models.servicing_publicapi_transfers_permission_assigned_by_tenant_dto import ServicingPublicapiTransfersPermissionAssignedByTenantDTO
from visier_api_administration.models.servicing_publicapi_transfers_permission_assigned_for_local_tenant_dto import ServicingPublicapiTransfersPermissionAssignedForLocalTenantDTO
from visier_api_administration.models.servicing_publicapi_transfers_permission_assigned_user_dto import ServicingPublicapiTransfersPermissionAssignedUserDTO
from visier_api_administration.models.servicing_publicapi_transfers_permission_assigned_users_dto import ServicingPublicapiTransfersPermissionAssignedUsersDTO
from visier_api_administration.models.servicing_publicapi_transfers_permission_bulk_operation_response_dto import ServicingPublicapiTransfersPermissionBulkOperationResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_permission_dto import ServicingPublicapiTransfersPermissionDTO
from visier_api_administration.models.servicing_publicapi_transfers_permission_error_dto import ServicingPublicapiTransfersPermissionErrorDTO
from visier_api_administration.models.servicing_publicapi_transfers_permission_failure_dto import ServicingPublicapiTransfersPermissionFailureDTO
from visier_api_administration.models.servicing_publicapi_transfers_permission_success_dto import ServicingPublicapiTransfersPermissionSuccessDTO
from visier_api_administration.models.servicing_publicapi_transfers_production_version_api_operation_request_dto import ServicingPublicapiTransfersProductionVersionAPIOperationRequestDTO
from visier_api_administration.models.servicing_publicapi_transfers_production_version_api_operation_response_dto import ServicingPublicapiTransfersProductionVersionAPIOperationResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_production_versions_api_operation_request_dto import ServicingPublicapiTransfersProductionVersionsAPIOperationRequestDTO
from visier_api_administration.models.servicing_publicapi_transfers_production_versions_api_operation_response_dto import ServicingPublicapiTransfersProductionVersionsAPIOperationResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_profile_assigned_for_accessible_tenant_dto import ServicingPublicapiTransfersProfileAssignedForAccessibleTenantDTO
from visier_api_administration.models.servicing_publicapi_transfers_profile_assigned_for_local_tenant_dto import ServicingPublicapiTransfersProfileAssignedForLocalTenantDTO
from visier_api_administration.models.servicing_publicapi_transfers_profile_get_api_response_dto import ServicingPublicapiTransfersProfileGetAPIResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_profiles_get_api_response_dto import ServicingPublicapiTransfersProfilesGetAPIResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_project_commits_api_response_dto import ServicingPublicapiTransfersProjectCommitsAPIResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_project_dto import ServicingPublicapiTransfersProjectDTO
from visier_api_administration.models.servicing_publicapi_transfers_project_operation_request_dto import ServicingPublicapiTransfersProjectOperationRequestDTO
from visier_api_administration.models.servicing_publicapi_transfers_project_operation_response_dto import ServicingPublicapiTransfersProjectOperationResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_property_access_config_dto import ServicingPublicapiTransfersPropertyAccessConfigDTO
from visier_api_administration.models.servicing_publicapi_transfers_property_set_config_dto import ServicingPublicapiTransfersPropertySetConfigDTO
from visier_api_administration.models.servicing_publicapi_transfers_reduced_error_dto import ServicingPublicapiTransfersReducedErrorDTO
from visier_api_administration.models.servicing_publicapi_transfers_reduced_tenant_code_error_dto import ServicingPublicapiTransfersReducedTenantCodeErrorDTO
from visier_api_administration.models.servicing_publicapi_transfers_reduced_user_id_error_dto import ServicingPublicapiTransfersReducedUserIdErrorDTO
from visier_api_administration.models.servicing_publicapi_transfers_related_analytic_object_dto import ServicingPublicapiTransfersRelatedAnalyticObjectDTO
from visier_api_administration.models.servicing_publicapi_transfers_role_modules_config_dto import ServicingPublicapiTransfersRoleModulesConfigDTO
from visier_api_administration.models.servicing_publicapi_transfers_securable_dimension_dto import ServicingPublicapiTransfersSecurableDimensionDTO
from visier_api_administration.models.servicing_publicapi_transfers_securable_property_dto import ServicingPublicapiTransfersSecurablePropertyDTO
from visier_api_administration.models.servicing_publicapi_transfers_shareable_data_access_set import ServicingPublicapiTransfersShareableDataAccessSet
from visier_api_administration.models.servicing_publicapi_transfers_sources_api_operation_request_dto import ServicingPublicapiTransfersSourcesAPIOperationRequestDTO
from visier_api_administration.models.servicing_publicapi_transfers_static_dimension_filter_dto import ServicingPublicapiTransfersStaticDimensionFilterDTO
from visier_api_administration.models.servicing_publicapi_transfers_successful_accessible_tenant_profile_assignment_dto import ServicingPublicapiTransfersSuccessfulAccessibleTenantProfileAssignmentDTO
from visier_api_administration.models.servicing_publicapi_transfers_successful_local_tenant_profile_assignment_dto import ServicingPublicapiTransfersSuccessfulLocalTenantProfileAssignmentDTO
from visier_api_administration.models.servicing_publicapi_transfers_target_tenant_code_dto import ServicingPublicapiTransfersTargetTenantCodeDTO
from visier_api_administration.models.servicing_publicapi_transfers_tenant_code_error_dto import ServicingPublicapiTransfersTenantCodeErrorDTO
from visier_api_administration.models.servicing_publicapi_transfers_user_creation_api_request_dto import ServicingPublicapiTransfersUserCreationAPIRequestDTO
from visier_api_administration.models.servicing_publicapi_transfers_user_get_api_response_dto import ServicingPublicapiTransfersUserGetAPIResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_user_group_assigned_for_local_tenant_dto import ServicingPublicapiTransfersUserGroupAssignedForLocalTenantDTO
from visier_api_administration.models.servicing_publicapi_transfers_user_id_error_dto import ServicingPublicapiTransfersUserIdErrorDTO
from visier_api_administration.models.servicing_publicapi_transfers_user_property_dto import ServicingPublicapiTransfersUserPropertyDTO
from visier_api_administration.models.servicing_publicapi_transfers_user_update_api_request_dto import ServicingPublicapiTransfersUserUpdateAPIRequestDTO
from visier_api_administration.models.servicing_publicapi_transfers_users_api_error_message_dto import ServicingPublicapiTransfersUsersAPIErrorMessageDTO
from visier_api_administration.models.servicing_publicapi_transfers_users_api_failure_dto import ServicingPublicapiTransfersUsersAPIFailureDTO
from visier_api_administration.models.servicing_publicapi_transfers_users_api_response_dto import ServicingPublicapiTransfersUsersAPIResponseDTO
from visier_api_administration.models.servicing_publicapi_transfers_users_api_success_dto import ServicingPublicapiTransfersUsersAPISuccessDTO
from visier_api_administration.models.servicing_publicapi_transfers_users_creation_api_request_dto import ServicingPublicapiTransfersUsersCreationAPIRequestDTO
from visier_api_administration.models.servicing_publicapi_transfers_users_delete_api_request_dto import ServicingPublicapiTransfersUsersDeleteAPIRequestDTO
from visier_api_administration.models.servicing_publicapi_transfers_users_update_api_request_dto import ServicingPublicapiTransfersUsersUpdateAPIRequestDTO
from visier_api_administration.models.servicing_publicapi_transfers_users_update_api_user_dto import ServicingPublicapiTransfersUsersUpdateAPIUserDTO
from visier_api_administration.models.source_import_result_summary_dto import SourceImportResultSummaryDTO
from visier_api_administration.models.sources_api_put_response_dto import SourcesAPIPutResponseDTO
from visier_api_administration.models.status import Status
from visier_api_administration.models.systemstatus_publicapi_transfers_system_status_dto import SystemstatusPublicapiTransfersSystemStatusDTO
from visier_api_administration.models.user_creation_api_response_dto import UserCreationAPIResponseDTO



# coding: utf-8

"""
    Visier Administration APIs

    Visier APIs for managing your tenant or tenants in Visier. You can programmatically manage user accounts in Visier, the profiles and permissions assigned to users, and to make changes in projects and publish projects to production. Administrating tenant users can use administration APIs to manage their analytic tenants and consolidated analytics tenants.<br>**Note:** If you submit API requests for changes that cause a project to publish to production (such as assigning permissions to users or updating permissions), each request is individually published to production, resulting in hundreds or thousands of production versions. We recommend that you use the `ProjectID` request header to make changes in a project, if `ProjectID` is available for the API endpoint.

    The version of the OpenAPI document: 22222222.99201.1793
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from visier_api_administration.models.servicing_publicapi_transfers_permission_dto import ServicingPublicapiTransfersPermissionDTO
from typing import Optional, Set
from typing_extensions import Self

class AdminPermissionsListDTO(BaseModel):
    """
    AdminPermissionsListDTO
    """ # noqa: E501
    permissions: Optional[List[ServicingPublicapiTransfersPermissionDTO]] = Field(default=None, description="The list of permissions that will be created or updated")
    __properties: ClassVar[List[str]] = ["permissions"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AdminPermissionsListDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in permissions (list)
        _items = []
        if self.permissions:
            for _item_permissions in self.permissions:
                if _item_permissions:
                    _items.append(_item_permissions.to_dict())
            _dict['permissions'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AdminPermissionsListDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "permissions": [ServicingPublicapiTransfersPermissionDTO.from_dict(_item) for _item in obj["permissions"]] if obj.get("permissions") is not None else None
        })
        return _obj


